<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="94"/>
        <source>Take a screenshot</source>
        <translation>Wykonaj zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="98"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[PLIK1, PLIK2,…]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../../upload/imageshackupload.cpp" line="49"/>
        <source>unknown error response</source>
        <translation>nieznana odpowiedź błędu</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../../upload/imgurupload.cpp" line="46"/>
        <source>unknown error response</source>
        <translation>nieznana odpowiedź błędu</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="145"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="146"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - prosta i szybka przeglądarka obrazów

Prawa autorskie (C) 2013
Projekt LXQt: https://lxqt.org/

Autorzy:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="255"/>
        <source>Open File</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="256"/>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Image files (%1)</source>
        <translation>Pliki obrazów (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Open directory</source>
        <translation>Otwórz katalog</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Save File</source>
        <translation>Zapisz plik</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Ładowanie…) - Przeglądarka obrazów</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="544"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Ładowanie nie powiodło się) - Przeglądarka obrazów</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="548"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Przeglądarka obrazów</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="584"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Przeglądarka obrazów</translation>
    </message>
    <message>
        <source>%1 (Loading...) - Image Viewer</source>
        <translation type="vanished">%1 (Wczytywanie…) - Przeglądarka obrazów</translation>
    </message>
    <message>
        <source>%1 (Failed to Load) - Image Viewer</source>
        <translation type="vanished">%1 (Błąd wczytywania) - Przeglądarka obrazów</translation>
    </message>
    <message>
        <source>%1 (%2x%3) - Image Viewer</source>
        <translation type="vanished">%1 (%2x%3) - Przeglądarka obrazów</translation>
    </message>
    <message>
        <source>Image Viewer</source>
        <translation type="vanished">Przeglądarka obrazów</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="851"/>
        <source>Thumbnails</source>
        <translation>Miniaturki</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="48"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="124"/>
        <source>Start</source>
        <translation>Rozpocznij</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="127"/>
        <source>Stop</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="130"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="137"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Przeglądarka obrazów</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="162"/>
        <source>&amp;About</source>
        <translation>&amp;O programie</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>&amp;Open File</source>
        <translation>O&amp;twórz plik</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="175"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>&amp;Save</source>
        <translation>&amp;Zapisz</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="188"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Save &amp;As</source>
        <translation>Z&amp;apisz jako</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="201"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="214"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Zoom &amp;In</source>
        <translation>Po&amp;większ</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="vanished">Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Zoom &amp;Out</source>
        <translation>Po&amp;mniejsz</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="240"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="250"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Kopiuj do schowka</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="260"/>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>Next File</source>
        <translation>Następny plik</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">W prawo</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="276"/>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>Previous File</source>
        <translation>Poprzedni plik</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">W lewo</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="227"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="266"/>
        <source>PgDown</source>
        <translation>Page Down</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="282"/>
        <source>PgUp</source>
        <translation>Page Up</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="292"/>
        <source>Original Size</source>
        <translation>Rozmiar oryginalny</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="295"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="305"/>
        <source>&amp;Fit</source>
        <translation>Dopa&amp;sowanie</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="315"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Ob&amp;róć zgodnie z ruchem wskazówek zegara</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="325"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Obróć prze&amp;ciwnie do ruchu wskazówek zegara</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="330"/>
        <source>P&amp;references</source>
        <translation>P&amp;referencje</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="335"/>
        <source>&amp;Print</source>
        <translation>&amp;Drukuj</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="338"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="348"/>
        <source>First File</source>
        <translation>Pierwszy plik</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="351"/>
        <source>Home</source>
        <translation>Początek</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="361"/>
        <source>Last File</source>
        <translation>Ostatni plik</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="364"/>
        <source>End</source>
        <translation>Koniec</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="374"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nowe okno</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="377"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="382"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Od&amp;bij w poziomie</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="392"/>
        <source>Capture Screenshot</source>
        <translation>Przechwyć zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="400"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Pełny ekran</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="403"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="408"/>
        <source>Flip &amp;Vertically</source>
        <translation>Odbi&amp;j w pionie</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="418"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Wklej ze schowka</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="431"/>
        <source>&amp;Slide Show</source>
        <translation>Pokaz &amp;slajdów</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="441"/>
        <source>&amp;Delete</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="444"/>
        <source>Del</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="452"/>
        <source>Show Thumbnails</source>
        <translation>Pokaż miniaturki</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="457"/>
        <source>File Properties</source>
        <translation>Właściwości pliku</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="465"/>
        <source>Open &amp;Directory</source>
        <translation>Otwórz &amp;katalog</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="468"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="476"/>
        <source>Upload</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="479"/>
        <source>Upload the image</source>
        <translation>Wyślij obraz</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>Pomo&amp;c</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="78"/>
        <source>Go</source>
        <translation>Przejdź</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edycja</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="123"/>
        <source>Toolbar</source>
        <translation>Pasek narzędziowy</translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="obsolete">Pasek narzędzi</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Zestaw ikon:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Kolor tła:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Kolor tła dla pełnego ekranu:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Interwał pokazu slajdów (sekundy):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>TODO: Add configuration options here</source>
        <translation type="vanished">Do zrobienia: Dodać tutaj opcje konfiguracyjne</translation>
    </message>
    <message>
        <source>Tab 1</source>
        <translation type="vanished">Karta 1</translation>
    </message>
    <message>
        <source>Tab 2</source>
        <translation type="vanished">Karta 2</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Wykonaj zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Obszar</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Cały ekran</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Tylko bieżące okno</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Przechwyć fragment ekranu</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Dołącz kursor myszy</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> sekund</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Opóźnienie:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Dołącz tytuł okna i obramowanie</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Wyślij</translation>
    </message>
</context>
</TS>
